@@ -39,7 +39,7 @@ my $address = 18; # Factory default
 
 $port = $main::opt_port if defined $main::opt_port;
 $address = $main::opt_address if defined $main::opt_address;
-$Device::GPIB::Controller::debug = 1 if $main::opt_debug;
+Device::GPIB::Controller::enableDebug(1) if $main::opt_debug;
 
 my $d = Device::GPIB::Controller->new($port);
 exit unless $d;
