@@ -42,7 +42,7 @@ my $function = 'DCV';
 
 $port = $main::opt_port if defined $main::opt_port;
 $address = $main::opt_address if defined $main::opt_address;
-$Device::GPIB::Controller::debug = 1 if $main::opt_debug;
+Device::GPIB::Controller::enableDebug(1) if $main::opt_debug;
 $function =  uc($main::opt_function) if defined $main::opt_function;
 
 my $d = Device::GPIB::Controller->new($port);
